# Images ToolBox

A set of tools for Data Scientist working on Computer Vision. Created for rapid prototyping.

[![PyPI version](https://img.shields.io/pypi/v/itb.svg)](https://pypi.org/project/itb/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/itb.svg)](https://pypi.python.org/pypi/itb/)
[![Downloads](https://static.pepy.tech/badge/itb)](https://pepy.tech/project/itb)

# Examples
All code of the library is presented as examples in the following colab notebooks:

### Examples basics: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/grafiszti/itb/blob/master/notebooks/Examples%20basics.ipynb)
### Examples drawing on images: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/grafiszti/itb/blob/master/notebooks/Examples%20drawing%20on%20images.ipynb)
